#!/usr/bin/perl
# Copyright (C) 2007-2008 Ian Korf
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# Last updated by: $Author: iankorf $
# Last updated on: $Date: 2008/08/11 18:30:00 $

use strict; use warnings;
use FAlite;
use IME;
use Getopt::Std;
use vars qw($opt_d $opt_a $opt_t);

my $CLIP_D = 5;
my $CLIP_A = 10;
getopts('d:a:t');
$CLIP_D = $opt_d if $opt_d;
$CLIP_A = $opt_a if $opt_a;
my $TAB = $opt_t ? 1 : 0;

die "
usage: imeter.pl [options] <parameter file> <fasta file>
options:
  -d <int> clip donor site nt    [default $CLIP_D]
  -a <int> clip acceptor site nt [default $CLIP_A]
  -t       tab between fields    [default spaces]
" unless @ARGV == 2;

my ($PARAM, $FASTA) = @ARGV;

# read imeter parameter file
my ($model, $wordsize, $info) = IME::read_imeter_parameter_file($PARAM);

# main loop
my $fasta;
if ($FASTA eq '-') {
	$fasta = new FAlite(\*STDIN);
} else {
	open(IN, $FASTA) or die;
	$fasta = new FAlite(\*IN);
}
while (my $intron = $fasta->nextEntry) {
	my ($id) = $intron->def =~ /^>(\S+)/;
	my $seq = uc $intron->seq;
	$seq = substr($seq, $CLIP_D, length($seq) - $CLIP_D - $CLIP_A);
	my $score = IME::score_intron($model, $wordsize, $seq);
	if ($TAB) {printf "%s\t%.3f\n", $id, $score}
	else      {printf "%-20s%.3f\n", $id, $score}
}
close IN;

